import React from "react";
import { Cell, Grid } from "@webiny/ui/Grid";
import RenderFieldElement from "./RenderFieldElement";
import {
    CmsEditorContentModel,
    CmsEditorField,
    CmsEditorFieldsLayout,
    BindComponent
} from "~/types";

interface FieldsProps {
    Bind: BindComponent;
    contentModel: CmsEditorContentModel;
    fields: CmsEditorField[];
    layout: CmsEditorFieldsLayout;
    gridClassName?: string;
}

const getFieldById = (fields: CmsEditorField[], id: string): CmsEditorField | null => {
    return fields.find(field => field.id === id) || null;
};

export const Fields: React.FC<FieldsProps> = ({
    Bind,
    fields,
    layout,
    contentModel,
    gridClassName
}) => {
    return (
        <Grid className={gridClassName}>
            {layout.map((row, rowIndex) => (
                <React.Fragment key={rowIndex}>
                    {row.map(fieldId => (
                        <Cell span={Math.floor(12 / row.length)} key={fieldId}>
                            <RenderFieldElement
                                field={getFieldById(fields, fieldId) as CmsEditorField}
                                Bind={Bind}
                                contentModel={contentModel}
                            />
                        </Cell>
                    ))}
                </React.Fragment>
            ))}
        </Grid>
    );
};
