import React, { useCallback } from "react";
import { Image } from "@webiny/app/components";
import * as Ui from "@webiny/ui/ImageUpload";
import { createRenderImagePreview, imagePlugins } from "./utils";
import fileIcon from "../../fields/icons/round_insert_drive_file-24px.svg";
import { FormElementMessage } from "@webiny/ui/FormElementMessage";

const imagePreviewProps = {
    transform: { width: 300 },
    style: { width: "100%", height: 232, objectFit: "cover" }
};

const defaultStyles = {
    width: "100%",
    height: "auto"
};

interface ValidationStatus {
    isValid?: boolean;
    message?: string;
}
const defaultValidation: ValidationStatus = {
    isValid: undefined,
    message: undefined
};

export interface FileProps {
    url: string;
    onRemove: () => void;
    placeholder?: string;
    styles?: Record<string, any>;
    showFileManager?: () => void;
    validation?: {
        isValid?: boolean;
        message?: string;
    };
    description?: string;
}
const File: React.FC<FileProps> = props => {
    const { url, onRemove, placeholder, showFileManager, description } = props;

    const styles = props.styles || defaultStyles;
    const validation = props.validation || defaultValidation;

    const isImage = useCallback(url => {
        return imagePlugins.some(extension => url.includes(extension));
    }, []);

    const getImageSrc = useCallback(url => {
        if (url && isImage(url)) {
            return url;
        }
        return fileIcon;
    }, []);

    // TODO @ts-refactor figure out correct type
    const defaultRenderImagePreview = (renderImageProps: any) => (
        <Image {...renderImageProps} {...imagePreviewProps} />
    );

    const renderImagePreview = (url: string) => {
        if (url && !isImage(url)) {
            return createRenderImagePreview({ value: url, imagePreviewProps });
        }

        return defaultRenderImagePreview;
    };

    return (
        <>
            <Ui.Image
                renderImagePreview={renderImagePreview(url)}
                style={styles}
                value={url ? { src: getImageSrc(url) } : null}
                uploadImage={() => {
                    if (!showFileManager) {
                        return;
                    }
                    showFileManager();
                }}
                removeImage={onRemove}
                placeholder={placeholder}
                containerStyle={{ height: "auto" }}
            />
            {validation.isValid === false && (
                <FormElementMessage error>
                    {validation.message || "Invalid value."}
                </FormElementMessage>
            )}
            {validation.isValid !== false && description && (
                <FormElementMessage>{description}</FormElementMessage>
            )}
        </>
    );
};

export default File;
